pub enum FinishReason {
Safety,
Recitation,
Other,
}Expand description
Represents the reason why the Gemini API finished generating content.
Variants
Safety
Indicates that the generation was stopped due to safety concerns.
Recitation
Indicates that the generation was stopped due to content recitation.
Other
Represents any other reason for finishing content generation.
Implementations
Sourceimpl FinishReason
impl FinishReason
Sourcepub fn is_block_error(&self) -> bool
pub fn is_block_error(&self) -> bool
Determines if the finish reason is considered a block error.
Returns
true if the finish reason is either Safety or Recitation, false otherwise.